package edu.lawrence.androidquiz;

import androidx.appcompat.app.AppCompatActivity;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.AuthFailureError;
import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.google.gson.Gson;

public class QuestionActivity extends AppCompatActivity {

    private Gson gson;
    private RequestQueue queue;
    private Question[] questions = null;
    private int currentQuestion;
    private int studentID;
    private int quizID;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_question);
        Intent intent = getIntent();
        studentID = intent.getIntExtra(StudentPickerActivity.STUDENT_ID, 0);
        quizID = intent.getIntExtra(StudentPickerActivity.QUIZ_ID, 0);
        queue = Volley.newRequestQueue(this);
        gson = new Gson();
        requestQuestions();
    }

    private void requestQuestions() {
        String url = "http://10.0.2.2:8085/questions?quiz=" + quizID;
        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        loadQuestions(response);
                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Toast.makeText(getBaseContext(), "Could not fetch questions.", Toast.LENGTH_SHORT).show();
            }
        });

        queue.add(stringRequest);
    }

    private void loadQuestions(String json) {
        questions = gson.fromJson(json, Question[].class);
        currentQuestion = 0;
        showNextQuestion();
    }

    private void showNextQuestion() {
        Question q = questions[currentQuestion];
        String choices[] = q.getChoices().split(",");
        TextView text = (TextView) findViewById(R.id.question);
        text.setText(q.getQuestion());
        Button a = (Button) findViewById(R.id.buttonA);
        a.setText(choices[0]);
        Button b = (Button) findViewById(R.id.buttonB);
        b.setText(choices[1]);
        Button c = (Button) findViewById(R.id.buttonC);
        c.setText(choices[2]);
        Button d = (Button) findViewById(R.id.buttonD);
        d.setText(choices[3]);
    }

    public void clickA(View view) {
        answerQuestion("a");
    }

    public void clickB(View view) {
        answerQuestion("b");
    }

    public void clickC(View view) {
        answerQuestion("c");
    }

    public void clickD(View view) {
        answerQuestion("d");
    }

    private void answerQuestion(String answer) {
        Answer ans = new Answer();
        ans.setQuestion(questions[currentQuestion].getId());
        ans.setStudent(studentID);
        ans.setReponse(answer);
        String url = "http://10.0.2.2:8085/answers";
        StringRequest stringRequest = new StringRequest(Request.Method.POST, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        currentQuestion++;
                        if (currentQuestion >= questions.length)
                            finish();
                        else
                            showNextQuestion();
                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Toast.makeText(getBaseContext(), "Could not post answer.", Toast.LENGTH_SHORT).show();
            }
        }) {
            @Override
            public String getBodyContentType() {
                return "application/json; charset=utf-8";
            }

            @Override
            public byte[] getBody() throws AuthFailureError {
                return gson.toJson(ans).getBytes();
            }

        };
        queue.add(stringRequest);
    }
}