package edu.lawrence.androidquiz;

import androidx.appcompat.app.AppCompatActivity;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.google.gson.Gson;

public class QuizPickerActivity extends AppCompatActivity {

    private Gson gson;
    private RequestQueue queue;

    private Quiz[] quizzes = null;
    private int selected_quiz;
    private int studentID;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_quiz_picker);
        Intent intent = getIntent();
        studentID = intent.getIntExtra(StudentPickerActivity.STUDENT_ID,0);
        queue = Volley.newRequestQueue(this);
        gson = new Gson();
        selected_quiz = -1;
        requestQuizzes();
    }

    private void requestQuizzes() {
        String url = "http://10.0.2.2:8085/quizzes";
        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        showQuizzes(response);
                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Toast.makeText(getBaseContext(), "Could not fetch quizzes.", Toast.LENGTH_SHORT).show();
            }
        });

        queue.add(stringRequest);
    }

    private void showQuizzes(String json) {
        quizzes = null;
        String[] quizStrs = null;

        ListView quizList = (ListView) findViewById(R.id.quiz_list);

        quizzes = gson.fromJson(json,Quiz[].class);
        quizStrs = new String[quizzes.length];
        for(int n = 0;n < quizStrs.length;n++) {
            quizStrs[n] = quizzes[n].getTitle();
        }

        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this,
                android.R.layout.simple_list_item_1, quizStrs);
        quizList.setAdapter(adapter);

        quizList.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView,
                                    View view, int i, long l) {
                // remember the selection
                selected_quiz = i;
            }
        });
    }

    public void nextActivity(View view) {
        if(selected_quiz >= 0) {
            int id = quizzes[selected_quiz].getId();
            Intent intent = new Intent(this, QuestionActivity.class);
            intent.putExtra(StudentPickerActivity.QUIZ_ID, id);
            intent.putExtra(StudentPickerActivity.STUDENT_ID,studentID);
            startActivity(intent);
        }
    }
}