package edu.lawrence.androidquiz;

import androidx.appcompat.app.AppCompatActivity;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.google.gson.Gson;

public class StudentPickerActivity extends AppCompatActivity {
    private Gson gson;
    private RequestQueue queue;

    private Student[] students = null;
    private int selected_student;
    public final static String STUDENT_ID = "edu.lawrence.AndroidQuiz.STUDENT_ID";
    public final static String QUIZ_ID = "edu.lawrence.AndroidQuiz.QUIZ_ID";
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_student_picker);
        queue = Volley.newRequestQueue(this);
        gson = new Gson();
        selected_student = -1;
        requestStudents();
    }

    private void requestStudents() {
        String url = "http://10.0.2.2:8085/students";
        StringRequest stringRequest = new StringRequest(Request.Method.GET, url,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        showStudents(response);
                    }
                }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                Toast.makeText(getBaseContext(), "Could not fetch students.", Toast.LENGTH_SHORT).show();
            }
        });

        // Add the request to the RequestQueue.
        queue.add(stringRequest);
    }

    private void showStudents(String json) {
        students = null;
        String[] studentStrs = null;

        ListView studentList = (ListView) findViewById(R.id.student_list);

        students = gson.fromJson(json,Student[].class);
        studentStrs = new String[students.length];
        for(int n = 0;n < studentStrs.length;n++) {
            studentStrs[n] = students[n].getName();
        }


        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this,
                android.R.layout.simple_list_item_1, studentStrs);
        studentList.setAdapter(adapter);

        studentList.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView,
                                    View view, int i, long l) {
                // remember the selection
                selected_student = i;
            }
        });
    }

    public void nextActivity(View view) {
        if(selected_student >= 0) {
            int id = students[selected_student].getId();
            Intent intent = new Intent(this, QuizPickerActivity.class);
            intent.putExtra(STUDENT_ID, id);
            startActivity(intent);
        }
    }
}
